@@ -1,7 +1,7 @@
 '''
     This is a module named "nester.py" by Splendour
 '''
-def sortlist (sortedlist, level):
+def sortlist (sortedlist, level = 0):
     '''
         This is a function to print all the items in a list.
         "sortedlist" is the target list. It can be a single list,
